ThermoState
===========

This package provides a wrapper around
`CoolProp <https://github.com/CoolProp/CoolProp>`__ that more naturally
allows management of a thermodynamic state.

Continuous Integration Status
=============================

TravisCI: |Build Status| Appveyor: |Build status| |codecov|

Anaconda Package Version
========================

|Anaconda-Server Badge| |Anaconda-Server Badge|

Change Log
==========

All notable changes to this project will be documented in this file.

The format is based on `Keep a Changelog <http://keepachangelog.com/>`__
and this project adheres to `Semantic
Versioning <http://semver.org/>`__.

`Unreleased <https://github.com/bryanwweber/thermostate/compare/v0.2.2...master>`__
-----------------------------------------------------------------------------------

Added
~~~~~

Changed
~~~~~~~

Fixed
~~~~~

Removed
~~~~~~~

`0.2.2 <https://github.com/bryanwweber/thermostate/compare/v0.2.1...v0.2.2>`__ - 13-APR-2017
--------------------------------------------------------------------------------------------

Added
~~~~~

-  Oxygen (O2) is available as a substance
-  Nitrogen (N2) is available as a substance

Fixed
~~~~~

-  Deploy doctr to the root directory (see
   `drdoctr/doctr#157 <https://github.com/drdoctr/doctr/issues/157>`__
   and
   `drdoctr/doctr#160 <https://github.com/drdoctr/doctr/issues/160>`__)

`0.2.1 <https://github.com/bryanwweber/thermostate/compare/v0.2.0...v0.2.1>`__
------------------------------------------------------------------------------

Added
~~~~~

-  Carbon dioxide is available as a substance
-  The software version is available as the module-level ``__version__``
   attribute

`0.2.0 <https://github.com/bryanwweber/thermostate/compare/v0.1.7...v0.2.0>`__
------------------------------------------------------------------------------

Added
~~~~~

-  Equality comparison of ``State`` instances

Changed
~~~~~~~

-  Improve several error messages
-  Refactor property getting/setting to use less boilerplate code
-  Preface all class attributes with ``_``
-  Refactor ``_set_properties`` to use CoolProp low-level API

`0.1.7 <https://github.com/bryanwweber/thermostate/compare/v0.1.6...v0.1.7>`__
------------------------------------------------------------------------------

Added
~~~~~

-  Phase as a gettable attribute of the State
-  Isobutane is an available substance
-  Add cp and cv to Tutorial

Changed
~~~~~~~

-  Updated Tutorial with more detail of setting properties
-  Fail Travis when a single command fails

`0.1.6 <https://github.com/bryanwweber/thermostate/compare/v0.1.5...v0.1.6>`__
------------------------------------------------------------------------------

Added
~~~~~

-  Tutorial in the docs using ``nbsphinx`` for formatting
-  Specific heat capacities at constant pressure and volume are now
   accesible via cp and cv attributes

Changed
~~~~~~~

-  Offset units are automatically converted to base units in Pint

`0.1.5 <https://github.com/bryanwweber/thermostate/compare/v0.1.4...v0.1.5>`__
------------------------------------------------------------------------------

Changed
~~~~~~~

-  Unknown property pairs are no longer allowed to be set

`0.1.4 <https://github.com/bryanwweber/thermostate/compare/v0.1.3...v0.1.4>`__
------------------------------------------------------------------------------

Fixed
~~~~~

-  Rename units module to abbreviations so it no longer shadows units
   registry in thermostate

`0.1.3 <https://github.com/bryanwweber/thermostate/compare/v0.1.2...v0.1.3>`__
------------------------------------------------------------------------------

Added
~~~~~

-  Common unit abbreviations in thermostate.EnglishEngineering and
   thermostate.SystemInternational

Fixed
~~~~~

-  Typo in CHANGELOG.md

`0.1.2 <https://github.com/bryanwweber/thermostate/compare/v0.1.1...v0.1.2>`__
------------------------------------------------------------------------------

Fixed
~~~~~

-  Fix Anaconda.org upload keys

`0.1.1 <https://github.com/bryanwweber/thermostate/compare/v0.1.0...v0.1.1>`__
------------------------------------------------------------------------------

Fixed
~~~~~

-  Only load pytest-runner if tests are being run

`0.1.0 <https://github.com/bryanwweber/thermostate/compare/491975d84317abdaf289c01be02567ab33bbc390...v0.1.0>`__
----------------------------------------------------------------------------------------------------------------

Added
~~~~~

-  First Release

.. |Build Status| image:: https://travis-ci.org/bryanwweber/thermostate.svg?branch=master
   :target: https://travis-ci.org/bryanwweber/thermostate
.. |Build status| image:: https://ci.appveyor.com/api/projects/status/my7m8k82udbkts9h/branch/master?svg=true
   :target: https://ci.appveyor.com/project/bryanwweber/thermostate/branch/master
.. |codecov| image:: https://codecov.io/gh/bryanwweber/thermostate/branch/master/graph/badge.svg
   :target: https://codecov.io/gh/bryanwweber/thermostate
.. |Anaconda-Server Badge| image:: https://anaconda.org/bryanwweber/thermostate/badges/version.svg
   :target: https://anaconda.org/bryanwweber/thermostate
.. |Anaconda-Server Badge| image:: https://anaconda.org/bryanwweber/thermostate/badges/downloads.svg
   :target: https://anaconda.org/bryanwweber/thermostate
